
*****/*Important:  Because total direct formal taxation is not included in household expenditure as calculated below, 
     MUST run AL_Tax after running this for accurate hhexp value*/

// Albania (LSMS 2005)

/* 
This do file calculates the following variables for each household
	hid     : household (hh) identifier
	labor   : a dummy which shows whether a household contributes labor
	days    : the number of days contributed
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	province: is the indicator of largest geographical unit, province or state
	weiclus : cluster level average of household weights
*/

clear
cap log close
cd\IT
log using "Results\AL_Exp.log", replace
set memo 50m
set more off



*************************************************************************************** Finding Labor contribution
use OData\AL\Data\social_capital_cl.dta, clear 

ren     m16_q12   labor              /* question: In the past year, any member of your household participate in any communal activity... */          
label variable labor "labor contribution dummy"
replace labor   = 0 if labor == 2    /* the answer "No" has been originally coded by 2, change to zero*/
ren     m16_q13   days               /* question: How many times in the past year */
label variable days "Amount of labor contribution"


// replacing the days with 0 instead of missing when we know that hh did not contribute any labor
replace days = 0 if days == . & labor ==0 

keep m0_q00 m0_q01 labor days  
ren  m0_q00 psu				 /*from label and because named PSU in other part of data*/ 


sort psu 
tempfile 01 
save `01'

*************************************************************************************************Finding Urban/Weight
use  OData\AL\Data\weights_psu.dta, clear

keep psu urban final_weights dist* commune village
ren     final  weight    /*rename for consistency among datasets*/


** recoding to a numeric variable with 1 for urban area and small towns and 0 otherwise 
encode  urban, gen(aa)   
drop urban
recode aa (1=.) (2 3=1) (4=0), gen(urban)   
drop  aa
	
sort  psu
merge psu using `01', uniqm
tab   _m*
drop  _m*
g      hid = 100*psu + m0_q01 	         /*constructing hid (hh identifier) as defined in other dta by LSMS*/

/*variables indicating district and village are string, we recode them to a numeric variable to be able to construct 
cluster and province variables */

encode district, gen(district_n)
encode village, gen(village_n)
g      cluster = village_n + 10^3 * district_n
ren    district_n province
ren    psu   cid
drop   m* dist*

sort hid
tempfile 02 
save `02'
keep cid cluster
duplicates drop
sort cid
save Results\080417psu_cluster_connect, replace

**************************************************************************************************** Finding Expenditure
use   OData\AL\Data\totcons05.dta
ren   hhid       hid             /*for consistency*/

sort  hid
merge hid using `02', uniqm
tab   _m*
drop  _m*


// constructing household expenditure variable
egen  hhexp = rsum(food sub1-sub11 edu elect fuel waterb phone computer durcons)   
    
sort hid
tempfile 03 
save `03'

**********************************************Kids/adults
use OData\AL\Data\household_rosterA_cl.dta,clear

ren   hhid       hid            /*for consistency*/
ren   m1a_q5y    age
keep  hid  age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// caculating number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults + hhkids + hhbabies                 
/*This estimation consistent with hhsize4 already in database, but covers more observations, so use this one*/

sort hid
merge hid using `03', unique
tab _
drop _
sort hid
tempfile 04 
save `04'

**********************************************Worker
use OData\AL\Data\labourA_cl.dta,clear
ren   hhid   hid

/*Worker is defined as one who has one of the three kind of work defined in the question2 to 4 of module 4
Though may include the free work (labor contribution) for community. 
*/

recode m4a_q02 (2=0) (missing=.), gen(worker)
replace worker = 1 if m4a_q03 == 1
replace worker = 1 if m4a_q04 == 1
collapse (sum) worker, by(hid)		/*To find the number of worker per hh*/
sort hid
merge hid using `04', unique
tab _
************************************************************
keep  cluster hid hhsize weight urban labor days hh* worker province cid
order cluster hid hhsize weight urban labor days hh* worker

foreach var in labor days{
sum `var' [aw=weight] 
sum `var' [aw=weight] if urban==1
sum `var' [aw=weight] if urban==0
}
sum days if labor==1
sum days if labor==1 & urban==1
sum days if labor==1 & urban==0


bys cluster: egen weiclus = mean(weight)
sort hid

save Results\AL_Exp.dta, replace
log close
