/* 
This do file calculates the following variables for each household
	hid     : household(hh) indentifier
	labor/money : a dummy which shows whether a household contributes labor/money
	Any     : a dummy which shows whether a household contributes labor OR money
	days    : the number of days contributed
	dollars : the amount of money contributed in local money and for specific duration ( for Indonesia)
	hhsize  : the number of hh members (noemally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh which has to be considered
	cluster : is the indicator of smallest geographical unit, village or community
	weiclus : cluster level average of household weights  
*/

clear 
cap log close
cd\IT
log using "Results\V02_Exp.log", replace
set memo 50m
set more off

*************************************************************************************************************Labor 
use       "OData\V02\Data\muc3.dta", clear                   
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))

// indicating whether individual is working or not
g laborind = m3c18==1
// determining number of days this individual contributed
g days     = m3c19
// constructing a parameter "contrad" which shows the individual with contradictions in data
g       contrad = 0
replace contrad = 1 if laborind==1 & days==0

collapse (sum) days laborind contrad, by (hid)
// creating a dummy variable for at least one of the member of household contibuting labor
gen labor  = laborind > 0

drop laborind 
sort hid
tempfile 01
save `01'

*************************************************************************************************************Money
use "OData\V02\Data\muc6b34.dta", clear 
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
ren m6b3c2h402 dollars                                  /* For money quantity*/
collapse (sum) dollars, by(hid)


sort hid
merge hid using `01', unique
tab _
drop _

// creating money and any contribution dummies
g   money = dollars > 0
g   any   = money + labor >=1

sort hid
tempfile 02
save `02'

*************************************************************************************************
use "OData\V02\Data\hhexpe02", clear
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))


ren wt30     weight

ren xa       cluster		
label var cluster "Based on XA: Commune/Ward/Town"
g  urban  = urban02==1

sort hid
merge hid using `02', unique
tab _
drop _
sort hid
tempfile 03
save `03'

***********************************************************************Kids/adults
use OData\V02\Data\muc1.DTA, clear
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
ren   m1c5    age
keep  hid     age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults + hhkids + hhbabies                   
sort hid
merge hid using `03', unique
tab _
drop _
sort hid
tempfile 04
save `04'

************************************************************ Workers
use "OData\v02\Data\muc3.dta", replace
g      hid   = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
ren    tinh  province 

// creating a dummy for worker individuals
recode m3c2 (2=0), gen(worker)

// collapsing to hh level, to find the number of worker per hh
collapse (sum) worker, by(hid province)
tab worker
sort hid 
merge hid using `04', unique
tab _

************************************************************
// calculating monthly hh expenditure
g   hhexp  = hhsize * (pcex2nom/12)

keep  cluster hid hhsize weight urban *any*  *labor* *money* days dollars hhexp hhadults hhkids hhbabies worker province contrad
order cluster hid hhsize weight urban *any*  *labor* *money* days dollars hh*
sort     hid
tempfile 06
save    `06'

// keeping list of hid with contradictions
keep if contrad>0 & contrad!=.
keep hid
sort hid

save Results\V02_contrad.dta, replace
use `06', clear

// dropping households with at least one contradicting member
drop if contrad>0 & contrad!=.

bys cluster: egen weiclus = mean(weight)
sort hid
save Results\V02_Exp.dta, replace
log close
