/* 
This do file calculates the following variables for each household
	hid     : household(hh) indentifier
	labor/money : a dummy which shows whether a household contributes labor/money (Here all contribution are toward construction activities)
	Any     : a dummy which shows whether a household contributes labor OR money
	days    : the number of days contributed
	dollars : the amount of money contributed in local money and for specific duration
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh which has to be considered
	cluster : is the indicator of smallest geographical unit, village or community
	weiclus : cluster level average of household weights  
*/

clear
cap log close
cd\IT 
log using "Results\ZA_Exp.log", replace

set memo 50m
set more off

**********************************************************

use "OData\ZA\data\SECT13.dta", clear

// dropping duplicate observations
duplicates drop

// dropping households with the same household identifiers
duplicates tag hid, gen(d)
tab d
drop if d!=0

// addressing the conditionality of s13`nn'q8 on s13`nn'q3
foreach nn of numlist 1/12 14 {
	replace s13`nn'q8 = . if s13`nn'q3 == 2
}                         

keep hid weight rururb s13*q8
drop s1313q8 s1315q8-s1324q8

gen urban = rururb=="2"
gen any   = 0
gen labor = 0
gen money = 0

// generating labor and money contribution variables
qui foreach nn of numlist 1/12 14 {
	foreach mm of numlist 2 3 5 {		
		replace labor=1 if s13`nn'q8==`mm'
	}
	foreach mm of numlist 1 4 5 {		
		replace money=1 if s13`nn'q8==`mm'
	}
}

replace any = money==1 | labor ==1	

keep hid weight urban any labor money			      /*do not keep hhsize here as it is almost always missing*/
sort hid
tempfile 01
save `01'

*************************************************************************************************************************Expenditure
use "OData\ZA\data\TOTEXP.dta", replace
duplicates drop

count
duplicates tag hid, gen(d)
tab d
drop if d!=0

sort  hid
merge hid using `01', unique
tab _

// generating cluster variable
g cluster = (province + district + csa + sea+string(urban)+stratum+centrlty)
drop hhsize
drop _
sort hid
tempfile 02
save `02'

***********************************************************************Kids/adults
clear
use OData\ZA\Data\HHROSTER.DTA
ren   s1q3b   age
keep  hid     age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults + hhkids + hhbabies                   

sort hid
merge hid using `02', unique
tab _
drop _
sort hid
tempfile 03
save `03'

*********************************************************************Workers
use "OData\ZA\Data\LABOR.dta", replace
tab s5q1, m

// defining dummy for workers
recode s5q1 (1/3=1) (4/10=0) (else=.), gen(worker)  

// collapsing to household level
collapse (sum) worker, by(hid)

tab worker, m
sort hid
merge hid using `03', unique
tab _

*********************************************************************
// calculating household expenditure
g hhexp   = pcexp*hhsize		

keep  cluster hid hhsize weight urban any* labor* money* hh* worker 
order cluster hid hhsize worker weight urban any* labor* money* hh*



// setting to missing few cases in which number of workers > hhsize
tab hhsize worker if worker > hhsize, missing
replace worker = . if worker > hhsize

bys cluster: egen weiclus = mean(weight)
sort hid
save Results\ZA_Exp, replace
log close
