/*
This do file prepares individual data which will be used e.g. for the calculation of an estimation of wage of each individual.

The ingredients:
	iid					: individual identification code
	education_y : proxy for the number of year of education for each individual
	age					: age of individual
	age_sq      : square of age of individual 
	gender_d		: gender dummy
	workerind		: dummy for workers
	worker      : number of workers per household
	urban       : equal to one if hh lives in urban area and 0 otherwise
	hhexp       : monthly household expenditure
	head        : dummy for head of hh
*/

clear
set memo 100m
/* Using these variables country per country, only for those that have "days" variable (the amount of labor contribution), 
   as only for these countries can estimate monetary value of labor contribution*/


cd\IT

*********************************************************************************************************************************AL (Albania)

*******************************************************************Education
use OData\AL\Data\educationB_cl.DTA, clear
ren      hhid       hid
g        iid = m2b_q00 + 100 * hid

/*
m2b_q05 is the grade and m2b_q04 is the level

m2b_q04:

            tabulation:  Freq.   Numeric  Label
                           277         0  None
                          8662         1  8 or 9 Years school
                          2438         2  Secondary general
                           273         3  Vocational 2-3  years
                          1590         4  Vocational 4/5
                           980         5  University - Albania
                            36         6  University - Abroad
                            25         7  Post-Graduate - Albania
                            10         8  Post-Graduate - Abroad

from Wikipedia:

    * Preschool education (erdhe or kopsht): 1-4 years
    * Primary education (9-vjeare): 9 years (It was 8 years before 2005)
    * Secondary education:
          o Regular (e mesme or gjimnaz): 3 years
          o Vocational or Technical (teknike): 2-5 years
    * Tertiary education:
          o Undergraduate (e larte): 4-5 years
          o Graduate: 1-3 years
    * Quaternary education (doktorat): 3 years
*/

// 0 for who declares "none" school or illiterate
g        education_y = 0          if  m2b_q04 == 0 | m2b_q03 == 2 
// the grade itself yields number of years of education for individuals in first level
replace  education_y = m2b_q05    if  m2b_q04 == 1     
// add the level + 9 for individuals in secondary general
replace  education_y = m2b_q05 + 9  if  m2b_q04 >= 2 & m2b_q04 <= 4  
// plus 13 for university students
replace  education_y = m2b_q05 + 13 if  m2b_q04 == 6 | m2b_q04 == 5
// assuming graduate as  4-year degree (13+4=17) 
replace  education_y = m2b_q05 + 17 if  m2b_q04 == 8 | m2b_q04 == 7

keep iid education_y
sort iid
tempfile education
save `education'  

***********************************************************************Age/Gender
use "OData\AL\Data\household_rosterA_cl.dta",clear
ren   hhid       hid
g iid = m1a_q00 + 100 * hid
// gender dummy, recode 2 to 0
recode  m1a_q02 (2=0), gen(gender_d)
// age and age squared
ren     m1a_q5y   age
g       age_sq  = age^2
ren   m1a_q03    head
keep hid iid age age_sq gender_d head
sort iid
merge iid using `education', unique
tab  _
drop _
sort hid
keep hid iid age age_sq gender_d education_y head 
sort hid
merge hid using "Results\AL_Exp.dta", uniqus
tab _
drop _
sort iid
tempfile 01
save `01'  


********************************************************************Worker
use "OData\AL\Data\labourA_cl.dta",clear
ren   hhid       hid
g iid = m4a_q00 + 100 * hid
//worker defined as individual who answers one of the following questions with yes: m4a_q02, m4a_q03, and m4a_q04
//issue: can include the free work (labor contribution) for community.  
recode m4a_q02 (2=0) (missing=.), gen(workerind)
replace workerind = 1 if m4a_q03 == 1
replace workerind = 1 if m4a_q04 == 1
sort iid
merge iid using `01', unique
tab  _
tab edu, m
sum edu, d
keep hid iid age age_sq gender_d education_y hhexp urban worker workerind province head weight
save Results\AL_ind_data, replace









*********************************************************************************************************************************ET (Ethiopia)
// In the case of Ethiopia, needed to use different round (2nd and 4th) of data in order to have education information of each individual
// in the 070629_ET_InSearchOfEdu.do, can see how find a manner to match the two round data
*******************************************************************Education
use "OData\ET\Data\11 3.3.99 roster.dta", clear    /*Data of round 4: education q11_b6*/
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
g  iid   = hid+string(pid,"%02.0f")
// dropping variable to avoid confusion as has same name as educational variable use from other data set
drop q12_1b
sort iid
tempfile 01
save `01'

use "OData\ET\Data\r2p1s2a.dta", clear   /*Data of round 2: education q12_1b*/
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q2,"%03.0f"))
g  iid   = hid+string(q12_1a,"%02.0f")
duplicates drop iid, force
sort iid
merge iid using `01', unique
tab _
keep iid q12_1b q11b_6

// education information
g education = q12_1b
// if the highest level question has not been answered, use the question q11b_6, which is highest grade completed
replace education = q11b_6 if education ==.
keep iid education

/*
           1   Never any schooling
           2   Some nursery school
           3   1st grade
           4   2nd grade
           5   3rd
           6   4th
           7   5th
           8   6th
           9   7th
          10   8th
          11   9th
          12   10th
          13   11th
          14   12th
          15   Higher educ. not complete (exclude university)
          17   Completed higher educ. (exclude Univ.)
          18   Univ. education complete
          19   Adult literacy prog. participated
          20   Other literacy prog.
          21   Religious educ
          30   Other
*/

// converting to number of years of education 
recode education (1 2 = 0) (15 17=14)(16 18 =16) (19 20 = 9) (21=12) (22/99=.)  , gen(education_y)   /*30 is the code for "other"*/
replace  education_y = education-2 if  education <= 14 & education >= 3    

keep education_y iid
sort iid 
tempfile 02 
save `02'

******************************************************************************** Age/Gender/Head of Household/Worker
use "OData\ET\Data\11 3.3.99 roster.dta", clear 
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
g  iid   = hid+string(pid,"%02.0f")
// create a gender dummy
recode sex (2=0), gen(gender_d)

//age and age-squared
ren    age4 age
g      age_sq  = age^2

//head of household
recode reltn4 (1=1)(-9 2/16=0) (missing=.), gen(head)

/* "activity" variable labels:

           3   Manual worker
           5   Weaver
          10   Farmer or family farm worker
          11   Domestic worker
          20   Manual worker
          21   Tailor
          22   Weaver
          23   Craftworker/Potter
          24   Blacksmith
          25   Foodseller
          26   Driver/Mechanic
          27   Skilled worker (Factory)
          30   Teacher
          31   Health worker
          32   Party official
          33   Soldier
          34   Trader
          40   Disabled
          50   Student
          51   Child, too young
          52   Child, help with domestic and farm work
          60   Looking for work
          70   Does not work/not looking for work
          80   Other
*/

//generate workind variable
recode    activity (10=1) (11=0) (20/34=1) (40/80=0) (else=.), gen(workerind)
sort hid
merge hid using "Results\ET_Exp.dta", uniqus
tab _
drop _

sort iid
merge iid using `02', uniqus
tab edu, m
sum edu, d
keep  hid iid age age_sq gender_d* education_y hhexp worker workerind province head weight
order hid iid age age_sq gender_d* education_y hhexp worker workerind province head

//dropping observations with contradictions
sort hid
merge hid using "Results\ET_contrad.dta", uniqus
tab _
drop if _ ==3
drop _
save Results\ET_ind_data, replace








*********************************************************************************************************************************GU (Guatemala)
*******************************************************************Education
use "OData\GU\Data\ECV09P05.dta", clear 
ren   hogar       hid
g     iid   = hid*100+caso

/*
Labels for p07b27a:
           1   ninguno
           2   preparatoria
           3   primaria
           4   educacion media
           5   educacion superior
           6   post-grado
           7   educacion adultos
*/

g       education_y = 0          if p07b27a == 1 | p07b27a == 2 | p07b27a == 9 
replace education_y = p07b27b    if p07b27a == 3 | p07b27a == 7 
replace education_y = p07b27b+6  if p07b27a == 4
replace education_y = p07b27b+12 if p07b27a == 5
replace education_y = p07b27b+16 if p07b27a == 6                

/*missing values of education are all less than 6 year-old*/

***********************************************************************Age/Gender
//gender
recode sexo (2=0), gen(gender_d)
//age and age squared
ren   edad    age
g      age_sq  = age^2

keep hid iid age age_sq gender_d education_y
sort hid
merge hid using "Results\GU_Exp.dta", uniqus

tab _
drop _
sort iid
tempfile 01
save `01'

***********************************************************************Worker
use "OData\GU\Data\ECV11P10", clear
ren   hogar       hid
g     iid   = hid*100+caso
// worker defined as answering yes to one the following questions: p10a01 or 02
recode p10a01 (2=0) (9=.), gen(workerind)
replace workerind = 1 if p10a02 == 1

sort iid
merge iid using `01', unique
tab _
drop _
sort iid
tempfile 02
save `02'

*************************************************************Head of household 
use "OData\GU\Data\ECV09P05", clear
ren   hogar       hid
g     iid   = hid*100+caso

recode p05a02 (1=1) (else = 0), gen(head) 
sort iid
merge iid using `02', unique
tab _

keep hid iid age age_sq gender_d education_y hhexp urban worker workerind province head weight
save Results\GU_ind_data, replace







*********************************************************************************************************************************ID07 (Indonesia)
*******************************************************************Education
use "OData\ID07\Data3\R_AR_01.dta",clear
ren rid hid
sort hid

merge hid using "Results\ID07_Exp", uniqus
tab _
drop if _merge==1
drop _ cluster province urban  any* labor* money* days* dollars* pcexp tot_tax tot_dir_tax tot_indir_tax hhexp t_* t_o* hh* worker

g   long   iid        = 100*real(hid)+rar00
format iid %12.0f
//values based on number of years of education necessary for each diploma
recode rar11 (1 = 3)(2=6)(3=9)(4=12)(5=14)(6=16)(7=18)(8=0)(else=.)  , gen(education_y)

***********************************************************************Age/Gender/Head of Household
//gender
recode rar03 (3=0), gen(gender_d)
//age and age squared
g      age        = 2007 - rar04_yy
g      age_sq     = age^2
//values for ror09: 1 for workers, and other options for student, unemployed, etc.
recode rar09 (1=1) (2/6 95=0) (missing=.), gen(workerind)
//head of household
recode rar02 (1=1) (2/95=0)(missing=.), gen(head)

sort hid
merge hid using "Results\ID07_Exp.dta", uniqus
tab _
keep hid iid age age_sq gender_d education_y hhexp worker workerind province head prov kabu keca weight

// dropping observations with contradictions
sort hid
merge hid using "Results\ID07_contrad.dta", uniqus
tab _
drop if _ ==3
drop _

save Results\ID07_ind_data, replace




***************************************************************************************************************************NI (Nicaragua)
*******************************************************************Education
use OData\NI\Data\EDUC.DTA, clear
ren   i00      hid
g   long  iid        = codper + 100* hid

g   education_y      = 0
replace education_y  = p4b08b     if p4b08a==3
replace education_y  = 6+ p4b08b  if p4b08a==4
replace education_y = 9 if p4b09 == 5 | p4b09 == 6 | p4b09 == 7
replace education_y  = 11+ p4b08b if p4b08a==8 	

keep iid edu
sort iid
tempfile 01
save `01'

***********************************************************************Age/Head of Household
use OData\NI\Data\DEMO.DTA, clear
ren    i00      hid
g long iid        = codper + 100* hid
ren    p204a    age
//head of household
recode p202 (1=1) (else=0), gen(head)

sort iid
merge iid using `01', unique
tab _
drop _

sort iid age head
tempfile 02
save `02'
***********************************************************************Worker
use OData\NI\Data\ACTEC.DTA, clear
ren    i00      hid
g long iid        = codper + 100* hid

g       workerind = p5a01
replace workerind = 0 if workerind ==2 

keep  iid workerind
sort  iid
merge iid using `02', unique
tab  _
drop _

sort hid
tempfile aa
save `aa'

replace workerind = 0 if age< 7
by hid: egen worker = total(workerind)
keep hid worker
duplicates drop
sort hid
merge hid using "Results\NI_Exp.dta", sort
tab _
drop _
sort hid
save "Results\NI_Exp.dta", replace

use `aa'
merge hid using "Results\NI_Exp.dta", uniqus
tab _
replace workerind = 0 if age<7


keep hid iid age education_y head workerind hhexp urban weight
save Results\NI_ind_data, replace




*********************************************************************************************************************NG04 (Nigeria)
*******************************************************************Education
use "OData\NG04\household roaster for each person.dta" , clear
g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")	 
g   iid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")+string(pid,"%02.0f")

//age
ren ageyears age
//head of household
recode relation (1=1) (2/95=0)(missing=.), gen(head)
recode sex (2=0), gen(gender_d)

keep hid iid gender_d age head
sort iid
tempfile 00
save `00', replace

use "OData\NG04\General Education.dta", clear

//years of education
gen education_y = .
replace ed = 0 if everattsch == 2
replace ed = 0 if highclassatt <= 2
replace ed = highclassatt - 2 if highclassatt >=3 & highclassatt <= 14
replace ed = 6 if highclassatt == 15
replace ed = 12 if highclassatt == 16
replace ed = 9 if highclassatt == 17 | highclassatt == 18 | highclassatt == 20 | highclassatt == 21 | highclassatt == 22
replace ed = 6 if highclassatt == 19
replace ed = 16 if highclassatt == 23
replace ed = 18 if highclassatt == 24

g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")	 
g   iid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")+string(pid,"%02.0f")

keep iid ed

sort iid
merge iid using `00', sort
tab _m 
drop _m

order hid iid age education_y head gender_d
sort hid

merge hid using "Results\NG04_Exp.dta", uniqus
tab _m

keep hid iid age education_y gender_d head weight
save Results\NG04_ind_data, replace








*********************************************************************************************************************************PA (Panama)
********************************************************************************************Education/Head/Gender/Age
use "OData\PA\Data\E03PE05.dta", clear
ren  form   hid
gen iid = 100*hid + p000

//head of household
gen head = 0
replace head = 1 if p002 == 1
replace head = . if p002 == .

//gender
** 1 = male 0 = female
recode p003 (2=0), gen(gender)

//age
ren p004 age

//years of education
gen education_y = .
replace ed = 0 if p546a == 0 | p546a == 1
replace ed = p546b if p546a == 2
replace ed = 6 + p546b if p546a == 3 | p546a == 4
replace ed = 6 if p546a == 5
replace ed = 12 + p546b if p546a == 6
replace ed = 12 if p546a == 7
replace ed = 16 if p546a == 8 & ed > 12
replace ed = 16 + p546b if p546a == 8


keep hid iid age education_y head gender 
sort hid
merge hid using "Results\PA_Exp.dta", uniqus

keep hid iid age education_y head hhexp urban weight
save Results\PA_ind_data, replace


*********************************************************************************************************************PH (Philippines)
*******************************************************************Education
use OData\PH\Data\memnew.DTA, clear
ren id    hid
ren idmem iid

// From the questionnaire we have meaning of all codes, which are separated in different groups 
// From "member data manual.xls", we know that 88 and 888 means not applicable
// Option 43 to 87 do not exist, thus we replace them with a missing value
recode c212 (0 1 =0) (99 = 0) (88 888=0) (43/87=.)(89/100=.)(missing=.), gen (education_y)  
replace  education_y = education_y-10 if education_y>=11 & education_y<=16
replace  education_y = education_y-14 if education_y>=21 & education_y<=25    
replace  education_y = 11 if education_y>=26 & education_y<=29
replace  education_y = education_y-19 if education_y>=31 & education_y<=34
replace  education_y = 15             if 35==education_y
replace  education_y = 16             if 41==education_y
replace  education_y = 18             if 42==education_y

***********************************************************************Age/Gender
//gender
recode b3 (2=0), gen(gender_d)
//age and age squared
ren    b4      age
g      age_sq  = age^2

/*
d1a20: Did _ work or had a job/business? 
Option 8 was "not applicable" which code as no, not a missing,
because for purposes here these people are not wage earners 
*/
//workerind
recode d1a20 (1=1) (2 8=0) (else=.), gen(workerind)
//head of household
recode b2 (1=1) (2/7=0)(missing=.), gen(head)

keep hid iid age age_sq gender_d education_y workerind head
sort hid
merge hid using "Results\PH_Exp.dta", uniqus
tab _

keep hid iid age age_sq gender_d education_y hhexp worker workerind province head weight

//dropping observations with contradictions
sort hid
merge hid using "Results\PH_contrad.dta", uniqus
tab _
drop if _ ==3
drop _
save Results\PH_ind_data, replace







************************************************************************************************************************************V02 (Vietnam)
*******************************************************************Education
use OData\V02\Data\muc2.DTA, clear
g iid         = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(matv,"%07.0f"))

/* questionnaire has two relevant questions:
m2c1.last grade finished and m2c3. highest degree obtained
use primarily the grade question unless for correction of university degree holders as the highest option in m2c1 question is 12, so all of them report 12
And also use the grade question to correct for few errors in grade data
*/

g        education_y = m2c1
// replace 9 years of education for few people who hold a lower secondary degree but report less than 9 grade
replace  education_y = 9  if m2c1<9 & m2c3 ==2
// replace 12 years of education for upper secondary diploma holders
replace  education_y = 12 if          m2c3 ==3
// 14 years for junior college diploma
replace  education_y = 14 if          m2c3 ==6
// 16 years for bachelor's
replace  education_y = 16 if          m2c3 ==7
// 18 years for master's  
replace  education_y = 18 if          m2c3 ==8
// 22 years for "Candidate/doctor"
replace  education_y = 22 if          m2c3 ==9

keep iid education_y
sort iid
tempfile education
save `education'

***********************************************************************Age/Gender
use OData\V02\Data\muc1.DTA, clear
g hid        = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
g iid        = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(matv,"%07.0f"))

//gender 
recode m1c2 (2=0), gen(gender_d)
//age and age squared
ren   m1c5     age
g     age_sq = age^2

//head of household
recode m1c3 (1=1) (else=0), gen(head)

keep hid iid age age_sq gender_d head
sort iid
merge iid using `education', unique
tab  _
drop _
sort hid
merge hid using "Results\V02_Exp.dta", uniqus
tab _
drop _
sort iid
tempfile 01
save `01'

************************************************************************Worker
use "OData\v02\Data\muc3.dta", replace
g      hid   = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
g      iid   = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(matv,"%07.0f"))

recode m3c2 (2=0), gen(workerind)
sort  iid
merge iid using `01', unique
tab _

keep hid iid province age age_sq gender_d education_y hhexp urban worker workerind head weight

//dropping observations with contradictions
sort hid
merge hid using "Results\V02_contrad.dta", uniqus
tab _
drop if _ ==3
drop _
save Results\V02_ind_data, replace


************************************************************************************************ZA (Zambia)

use "OData\ZA\Data\EDUCTION.DTA", clear
duplicates drop
gen iid = hid + string(pid,"%02.0f")

// dropping few entries with duplicate iids
duplicates tag iid, gen(tag)
tab tag
drop if tag > 0
drop tag

gen education_y = .

replace s4q2 = 0 if s4q2 == 88
replace s4q3 = 0 if s4q3 == 88
replace s4q8 = 0 if s4q8 == 88

// coding consistent pre-school answers as 0, if conflict between currently attending type and current grade(q.1 & 2), leave as missing
replace ed = 0	if s4q1 == 1 & s4q2 == .

// in grade school or higher
replace ed = s4q2	if s4q1 == 2
//if inconsistencies between grade currently attending and grade last year, make missing
replace ed = . if (s4q2 - s4q3 < 0 | s4q2 - s4q3 > 1) & (s4q2 != 13) & s4q2 != . & s4q3 != . 
**likely list previous year as 88(0) rather than 12 because in first year of post-secondary ed

// not in school
replace ed = s4q8	if s4q1 == 3 & s4q5 == 1
replace ed = 0	if s4q1 == 3 & s4q5 == 2

replace ed = .	if ed == 99
	
sort hid
tempfile 01
save `01', replace

use OData\ZA\Data\HHROSTER.DTA, clear
duplicates drop
gen iid = hid + string(pid,"%02.0f")

// dropping few entries with duplicate iids
duplicates tag iid, gen(tag)
tab tag
drop if tag > 0
drop tag

// age and age squared
rename s1q3b age
replace age = . if age == 99
gen age_sq = age^2
**unlikely such a big jump between 97 and 99, 99 used in other questions where not make sense, likely placeholder

// head of household
gen head = 1 if s1q4 == 1
replace head = 0 if s1q4 != 1 & s1q4!=.
// gender
recode s1q5 (2=0), gen(gender_d)
**1 = male 2 = female

sort iid
merge iid using `01', sort
tab _m
drop _m

**education roster only for 5 years old and higher
replace education_y = 0 if age < 5

keep hid weight iid head gender_d age age_sq education_y province
sort hid

merge hid using "Results\ZA_Exp.dta", uniqusing
tab _m
drop _m

keep hid iid age age_sq education_y gender_d head hhexp urban weight province
save Results\ZA_ind_data, replace

